@@ -32,43 +32,28 @@ DESCRIPTION="The GLib package contains low-level libraries useful for providing
 # GLib libraries - contain low-level core libraries for the GIMP Toolkit
 
 VERSION_EXT=$(basename $PKG_GLIB .tar.xz | cut -d "-" -f 2) 
+VERSION_EXT2=$(basename $PKG_GOBJECT .tar.xz | cut -d "-" -f 3) 
 
-if [ -f $PATCH_GLIB ]; then
-	patch -Np1 -i ../$PATCH_GLIB
+if [ -f ../$(basename $PATCH_GLIB) ]; then
+	patch -Np1 -i ../$(basename $PATCH_GLIB)
 fi
 
 if [ -e /usr/include/glib-2.0 ]; then
-    rm -rf /usr/include/glib-2.0.old &&
+    rm -rf /usr/include/glib-2.0.old
     mv -vf /usr/include/glib-2.0{,.old}
 fi
 
-[ -f /usr/bin/gio-querymodules ] && rm /usr/bin/gio-querymodules
-
-mkdir build &&
-cd    build &&
+mkdir build
+cd    build
 
 meson setup ..                  \
-      --prefix=/usr             \
-      --buildtype=release       \
-      -D introspection=disabled \
-      -D glib_debug=disabled    \
-      -D man-pages=enabled      \
-      -D sysprof=disabled 		\
-	  -D multiarch=true		
-	  #xattr
-	  #dtrace
-	  #systemtap
-	  #sysprof
-	  #force_posix_threads
-	  #installed_tests
-	  #nls
-	  #oss_fuzz
-	  #glib_debug
-	  #libelf
-	  #cairo
-	  #cairo-gobject
-	  #rnc2rng
-	  #valgrind
+	  --prefix=/usr             \
+	  --buildtype=release       \
+	  -D introspection=disabled \
+	  -D glib_debug=disabled    \
+	  -D man-pages=disabled     \
+      -D tests=false            \
+	  -D sysprof=disabled
 ninja
 
 # As root:
@@ -87,18 +72,13 @@ if [ -f ../../$(basename $PKG_GOBJECT) ]; then
 	ninja
 fi
 
-if [[ $(command -v gi-docgen) != "" ]]; then
-	# mkdir -p /usr/share/doc/glib-$VERSION_EXT
-	# cp -r ../docs/reference/{gio,glib,gobject} /usr/share/doc/glib-$VERSION_EXT
-
-	# if [ -f /usr/include/glib-2.0/glib/gurifuncs.h ]; then
-		# rm -f /usr/include/glib-2.0/glib/gurifuncs.h
-	# fi
-	sed "/docs_dir =/s|$| / 'glib-' + meson.project_version()|" \
-		-i ../docs/reference/meson.build                        &&
-	meson configure -D documentation=true                       &&
-	ninja
-fi
+# if [[ $(command -v gi-docgen) != "" ]]; then
+	# sed "/docs_dir =/s|$| / 'glib-' + meson.project_version()|" \
+		# -i ../docs/reference/meson.build
+	# meson configure -D documentation=true 
+	# ninja
+# fi
+#ERROR: Program 'rst2html5 rst2html5.py' not found or not executable
 
 ninja install
 
